# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['color_scheme_utils']

package_data = \
{'': ['*']}

install_requires = \
['stringcase>=1.2.0,<2.0.0']

entry_points = \
{'console_scripts': ['kitty-conf-extract-theme = '
                     'color_scheme_utils.kitty_conf_extract_theme:main']}

setup_kwargs = {
    'name': 'color-scheme-utils',
    'version': '0.1.2',
    'description': '',
    'long_description': '# color-scheme-utils\n\nA set of utilities for working with (terminal) color schemes / themes.\n\n- [color-scheme-utils](#color-scheme-utils)\n  - [List of utilities](#list-of-utilities)\n    - [kitty-conf-extract-theme](#kitty-conf-extract-theme)\n      - [Supported Output Formats](#supported-output-formats)\n      - [Usage:](#usage)\n  - [Installation](#installation)\n    - [pipx](#pipx)\n    - [pip](#pip)\n  - [Thanks](#thanks)\n\n## List of utilities\n\n### kitty-conf-extract-theme\n\nExtract the color settings from kitty configuration / theme files, convert them to different formats so that you can copy-paste them into the settings of your favorite terminal emulator.\n\n#### Supported Output Formats\n\nClick the titles to expand to see the example output generated from [kitty-theme\'s template.conf](https://github.com/kovidgoyal/kitty-themes/blob/master/template.conf)\n\n<details>\n  <summary>JSON</summary>\n\n```json\n{\n    "foreground": "#dddddd",\n    "background": "#000000",\n    "selection_foreground": "#000000",\n    "selection_background": "#fffacd",\n    "cursor": "#cccccc",\n    "cursor_text_color": "#111111",\n    "url_color": "#0087bd",\n    "active_border_color": "#00ff00",\n    "inactive_border_color": "#cccccc",\n    "bell_border_color": "#ff5a00",\n    "active_tab_foreground": "#000",\n    "active_tab_background": "#eee",\n    "inactive_tab_foreground": "#444",\n    "inactive_tab_background": "#999",\n    "mark1_background": "#98d3cb",\n    "mark2_background": "#f2dcd3",\n    "mark3_background": "#f274bc",\n    "black": "#000000",\n    "bright_black": "#767676",\n    "red": "#cc0403",\n    "bright_red": "#f2201f",\n    "green": "#19cb00",\n    "bright_green": "#23fd00",\n    "yellow": "#cecb00",\n    "bright_yellow": "#fffd00",\n    "blue": "#0d73cc",\n    "bright_blue": "#1a8fff",\n    "magenta": "#cb1ed1",\n    "bright_magenta": "#fd28ff",\n    "cyan": "#0dcdcd",\n    "bright_cyan": "#14ffff",\n    "white": "#dddddd",\n    "bright_white": "#ffffff"\n}\n```\n\n<!-- Two important rules:\n\nMake sure you have an empty line after the closing </summary> tag, otherwise the markdown/code blocks won\'t show correctly.\nMake sure you have an empty line after the closing </details> tag if you have multiple collapsible sections. -->\n</details>\n\n<details>\n  <summary>VS Code</summary>\n\n```json\n{\n    "workbench.colorCustomizations": {\n        "panel.background": "#000000",\n        "terminalCursor.foreground": "#cccccc",\n        "terminalCursor.background": "#111111",\n        "terminal.ansiBlack": "#000000",\n        "terminal.ansiBrightBlack": "#767676",\n        "terminal.ansiRed": "#cc0403",\n        "terminal.ansiBrightRed": "#f2201f",\n        "terminal.ansiGreen": "#19cb00",\n        "terminal.ansiBrightGreen": "#23fd00",\n        "terminal.ansiYellow": "#cecb00",\n        "terminal.ansiBrightYellow": "#fffd00",\n        "terminal.ansiBlue": "#0d73cc",\n        "terminal.ansiBrightBlue": "#1a8fff",\n        "terminal.ansiMagenta": "#cb1ed1",\n        "terminal.ansiBrightMagenta": "#fd28ff",\n        "terminal.ansiCyan": "#0dcdcd",\n        "terminal.ansiBrightCyan": "#14ffff",\n        "terminal.ansiWhite": "#dddddd",\n        "terminal.ansiBrightWhite": "#ffffff"\n    }\n}\n```\n\n<!-- Two important rules:\n\nMake sure you have an empty line after the closing </summary> tag, otherwise the markdown/code blocks won\'t show correctly.\nMake sure you have an empty line after the closing </details> tag if you have multiple collapsible sections. -->\n</details>\n\n<details>\n  <summary>Windows Terminal</summary>\n\n```json\n{\n    "name": "kitty",\n    "foreground": "#dddddd",\n    "background": "#000000",\n    "selectionForeground": "#000000",\n    "selectionBackground": "#fffacd",\n    "cursorColor": "#cccccc",\n    "black": "#000000",\n    "brightBlack": "#767676",\n    "red": "#cc0403",\n    "brightRed": "#f2201f",\n    "green": "#19cb00",\n    "brightGreen": "#23fd00",\n    "yellow": "#cecb00",\n    "brightYellow": "#fffd00",\n    "blue": "#0d73cc",\n    "brightBlue": "#1a8fff",\n    "purple": "#cb1ed1",\n    "brightPurple": "#fd28ff",\n    "cyan": "#0dcdcd",\n    "brightCyan": "#14ffff",\n    "white": "#dddddd",\n    "brightWhite": "#ffffff"\n}\n```\n\n<!-- Two important rules:\n\nMake sure you have an empty line after the closing </summary> tag, otherwise the markdown/code blocks won\'t show correctly.\nMake sure you have an empty line after the closing </details> tag if you have multiple collapsible sections. -->\n</details>\n\n<details>\n  <summary>kitty</summary>\n\n```\nforeground                     #dddddd\nbackground                     #000000\nselection_foreground           #000000\nselection_background           #fffacd\ncursor                         #cccccc\ncursor_text_color              #111111\nurl_color                      #0087bd\nactive_border_color            #00ff00\ninactive_border_color          #cccccc\nbell_border_color              #ff5a00\nactive_tab_foreground          #000\nactive_tab_background          #eee\ninactive_tab_foreground        #444\ninactive_tab_background        #999\nmark1_background               #98d3cb\nmark2_background               #f2dcd3\nmark3_background               #f274bc\nblack                          #000000\nbright_black                   #767676\nred                            #cc0403\nbright_red                     #f2201f\ngreen                          #19cb00\nbright_green                   #23fd00\nyellow                         #cecb00\nbright_yellow                  #fffd00\nblue                           #0d73cc\nbright_blue                    #1a8fff\nmagenta                        #cb1ed1\nbright_magenta                 #fd28ff\ncyan                           #0dcdcd\nbright_cyan                    #14ffff\nwhite                          #dddddd\nbright_white                   #ffffff\n\n```\n\n<!-- Two important rules:\n\nMake sure you have an empty line after the closing </summary> tag, otherwise the markdown/code blocks won\'t show correctly.\nMake sure you have an empty line after the closing </details> tag if you have multiple collapsible sections. -->\n</details>\n\n#### Usage:\n\n```\n$ kitty-conf-extract-theme -h\n\nusage: kitty-conf-extract-theme [-h] [-V] [-c KITTY_CONF_FILE] [-f {windowsterminal,vscode,kitty,json}] [-s]\n\nExtract the color scheme from a kitty theme / conf file\n\noptions:\n  -h, --help            show this help message and exit\n  -V, --version         show program\'s version number and exit\n  -c KITTY_CONF_FILE, --kitty-conf-file KITTY_CONF_FILE, --kitty-theme-file KITTY_CONF_FILE\n                        Kitty conf theme file (default: /Users/tscp/testdir/kitty-themes/template.conf)\n  -f {windowsterminal,vscode,kitty,json}, --output-format {windowsterminal,vscode,kitty,json}\n                        Output format (default: json)\n  -s, --sort-keys       Sort color name keys (default: False)\n```\n\n## Installation\n\n### pipx\n\nThis is the recommended installation method.\n\n```\n$ pipx install color-scheme-utils\n```\n\n### [pip](https://pypi.org/project/color-scheme-utils/)\n\n```\n$ pip install color-scheme-utils\n```\n\n## Thanks\n\n- [Kovid Goyal]https://kovidgoyal.net) for creating kitty and it\'s excellent documentation.\n- [vscode.one\'s theme editor](https://themes.vscode.one/)\n',
    'author': 'Teddy Xinyuan Chen',
    'author_email': '45612704+tddschn@users.noreply.github.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/tddschn/color-scheme-utils',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
